==> nocc-1.8.1.tbz: www/nocc/lang/gl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: gl.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Galician (Galego)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Toliño
 */

$lang_locale = 'gl_ES.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M %p';
$err_user_empty = 'O campo de rexistro está baleiro';
$err_passwd_empty = 'O campo do contrasinal está baleiro';
$alt_delete = 'Borrar as mensaxes seleccionadas';
$alt_delete_one = 'Borrar a mensaxe';
$alt_new_msg = 'Mensaxes novas';
$alt_reply = 'Responder ao autor';
$alt_reply_all = 'Responder a todos';
$alt_forward = 'Reenviar';
$alt_next = 'Seguinte';
$alt_prev = 'Anterior';
$title_next_page = 'Páxina seguinte';
$title_prev_page = 'Páxina anterior';
$title_next_msg = 'Mensaxe seguinte';
$title_prev_msg = 'Mensaxe anterior';
$html_on = 'en';
$html_theme_label = 'Tema:';
$html_welcome = 'Benvido a %1$s';
$html_login = 'Rexistro';
$html_passwd = 'Contrasinal';
$html_submit = 'Enviar';
$html_help = 'Axuda';
$html_server = 'Servidor';
$html_wrong = 'O rexistro ou o contrasinal son incorrectos';
$html_retry = 'Reintentar';
$html_remember = 'Lembrar as características';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Mensaxes por páxina:';
$html_preferences = 'Preferencias';
$html_full_name_label = 'Nome completo:';
$html_email_address_label = 'Enderezo de correo electrónico:';
$html_ccself = 'Recibir unha copia';
$html_hide_addresses = 'Agochar os enderezos';
$html_outlook_quoting = 'Citar ao estilo Outlook';
$html_reply_to = 'Responder a';
$html_use_signature = 'Usar a sinatura';
$html_signature = 'Sinatura';
$html_signature_label = 'Sinatura:';
$html_reply_leadin_label = 'Marxe da resposta:';
$html_prefs_updated = 'Preferencias actualizadas';
$html_manage_folders_link = 'Administrar os cartafoles IMAP';
$html_manage_filters_link = 'Xestionar os filtros de correo electrónico';
$html_use_graphical_smilies = 'Usar emoticonas gráficas';
$html_sent_folder_label = 'Copiar os correos enviados nun cartafol específico:';
$html_trash_folder_label = 'Mover os correos borrados a un cartafol específico:';
$html_colored_quotes = 'Comiñas coloreadas';
$html_display_struct = 'Mostrar o texto estruturado';
$html_send_html_mail = 'Enviar o correo en formato HTML';
$html_folders = 'Cartafoles';
$html_folders_create_failed = 'Non se puido crear o cartafol!';
$html_folders_sub_failed = 'Non se puido subscribir ao cartafol!';
$html_folders_unsub_failed = 'Non se puido deixar de subscribir ao cartafol!';
$html_folders_rename_failed = 'O cartafol non puido ser renomeado!';
$html_folders_updated = 'Cartafoles actualizados';
$html_folder_subscribe = 'Subscribirse a';
$html_folder_rename = 'Renomear';
$html_folder_create = 'Crear un novo cartafol chamado';
$html_folder_remove = 'Deixar a subscrición a';
$html_folder_delete = 'Borrar';
$html_folder_to = 'para';
$html_filter_remove = 'Borrar';
$html_filter_body = 'Corpo da mensaxe';
$html_filter_subject = 'Asunto da mensaxe';
$html_filter_to = 'Campo "Para"';
$html_filter_cc = 'Campo "Cc"';
$html_filter_from = 'Campo "De"';
$html_filter_change_tip = 'Para cambiar un filtro simplemente sobreescríbao.';
$html_reapply_filters = 'Reaplicar de novo todos os filtros';
$html_filter_contains = 'contén';
$html_filter_name = 'Nome do filtro';
$html_filter_action = 'Acción do filtro';
$html_filter_moveto = 'Mover a';
$html_select_one = '--Seleccione un--';
$html_and = 'E';
$html_new_msg_in = 'Novas mensaxes en';
$html_or = 'ou';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'as mensaxes seleccionadas a';
$html_gotopage = 'Ir á páxina';
$html_gotofolder = 'Ir ao cartafol';
$html_other_folders = 'Lista de cartafoles';
$html_page = 'Páxina';
$html_of = 'de';
$html_view_header = 'Ver a cabeceira';
$html_remove_header = 'Agochar a cabeceira';
$html_inbox = 'Bandexa de entrada';
$html_new_msg = 'Escribir';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a todos';
$html_forward = 'Reenviar';
$html_forward_short = 'Reenviar:';
$html_forward_info = 'A mensaxe reenviada será enviada como datos adxuntos desta.';
$html_delete = 'Borrar';
$html_new = 'Nova';
$html_mark = 'Borrar';
$html_att_label = 'Dato adxunto:';
$html_atts_label = 'Datos adxuntos';
$html_att_unknown = '[descoñecido]';
$html_attach = 'Adxuntar';
$html_attach_forget = 'Debe adxuntar o seu ficheiro antes de enviar a súa mensaxe!';
$html_attach_delete = 'Eliminar a selección';
$html_attach_none = 'Debe seleccionar o ficheiro a adxuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asunto';
$html_subject_label = 'Asunto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent = 'Enviado o:';
$html_wrote = 'escribiu';
$html_size = 'Tamaño';
$html_totalsize = 'Tamaño total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome do ficheiro';
$html_to = 'Para';
$html_to_label = 'Para:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cco:';
$html_nosubject = 'Sen asunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'Sen mensaxe.';
$html_logout = 'Saír';
$html_msg = 'Mensaxe';
$html_msgs = 'Mensaxes';
$html_configuration = 'Este servidor non está ben configurado!';
$html_priority = 'Prioridade';
$html_priority_label = 'Prioridade:';
$html_lowest = 'A menor';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'A maior';
$html_receipt = 'Pedir unha confirmación de chegada';
$html_select = 'Seleccionar';
$html_select_all = 'Inverter a selección';
$html_loading_image = 'Cargando a imaxe';
$html_send_confirmed = 'O seu correo foi enviado correctamente';
$html_no_sendaction = 'Non se especificou ningunha acción. Probe a activar o JavaScript.';
$html_error_occurred = 'Houbo un erro';
$html_prefs_file_error = 'Non se pode abrir o ficheiro de preferencias.';
$html_wrap = 'Número de caracteres aos que axustar as mensaxes enviadas a:';
$html_wrap_none = 'Sen axuste';
$html_usenet_separator = 'Usar o separador "-- \n" antes da sinatura';
$html_mark_as = 'Marcar como';
$html_read = 'lido';
$html_unread = 'non lido';
$html_encoding_label = 'Codificación de caracteres:';
$html_add = 'Engadir';
$html_contacts = '%1$s contactos';
$html_modify = 'Modificar';
$html_back = 'Voltar';
$html_contact_add = 'Engadir un novo contacto';
$html_contact_mod = 'Modificar un contacto';
$html_contact_first = 'Nome';
$html_contact_last = 'Apelidos';
$html_contact_nick = 'Alcume';
$html_contact_mail = 'Correo electrónico';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'da lista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'O número máximo de contactos é "%1$d"';
$html_contact_err2 = 'Non pode engadir un novo contacto';
$html_contact_err3 = 'Non ten dereitos de acceso á lista de contactos';
$html_contact_none = 'Non se puido atopar ningún contacto.';
$html_del_msg = 'Quere borrar as mensaxes seleccionadas?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaxe orixinal --';
$to_empty = 'O campo "Para" non pode estar baleiro!';
$html_images_warning = 'Pola súa seguridade, non se mostran as imaxes remotas.';
$html_images_display = 'Mostrar as imaxes';
$html_smtp_error_no_conn = 'Non se pode abrir conexión SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP non esperada:';
$lang_could_not_connect = 'Non se puido conectar co servidor';
$lang_invalid_msg_num = 'Número de mensaxes inválido';
$html_file_upload_attack = 'Posibilidade de ataque na carga do ficheiro';
$html_invalid_email_address = 'Enderezo de correo electrónico inválido';
$html_invalid_msg_per_page = 'Número inválido de mensaxes por páxina';
$html_invalid_wrap_msg = 'Ancho de axuste de mensaxe inválido';
$html_seperate_msg_win = 'Mensaxes nunha ventá separada';
$html_err_file_contacts = 'Non se pode abrir o ficheiro de contactos.';
$html_session_file_error = 'Non se pode abrir o ficheiro de inicio de sesión.';
$html_login_not_allowed = 'Este rexistro non está permitido para a conexión.';
$lang_err_send_delay = 'Debe agardar entre dous correos (%1$d segundos)';
$html_search = 'Procurar';

==> nocc-1.8.3.tbz: www/nocc/lang/gl.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: gl.php 2190 2010-05-23 19:27:44Z siebrand $
 */

/** Galician (Galego)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Toliño
 */

$lang_locale = 'gl_ES.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%d-%m-%Y';
$default_time_format = '%H:%M %p';
$err_user_empty = 'O campo de rexistro está baleiro';
$err_passwd_empty = 'O campo do contrasinal está baleiro';
$alt_delete = 'Borrar as mensaxes seleccionadas';
$alt_delete_one = 'Borrar a mensaxe';
$alt_new_msg = 'Mensaxes novas';
$alt_reply = 'Responder ao autor';
$alt_reply_all = 'Responder a todos';
$alt_forward = 'Reenviar';
$alt_next = 'Seguinte';
$alt_prev = 'Anterior';
$title_next_page = 'Páxina seguinte';
$title_prev_page = 'Páxina anterior';
$title_next_msg = 'Mensaxe seguinte';
$title_prev_msg = 'Mensaxe anterior';
$html_theme_label = 'Tema:';
$html_welcome = 'Benvido a %1$s';
$html_login = 'Rexistro';
$html_user_label = 'Usuario:';
$html_passwd_label = 'Contrasinal:';
$html_submit = 'Enviar';
$html_help = 'Axuda';
$html_server_label = 'Servidor:';
$html_wrong = 'O rexistro ou o contrasinal son incorrectos';
$html_retry = 'Reintentar';
$html_remember = 'Lembrar as características';
$html_lang_label = 'Lingua:';
$html_msgperpage_label = 'Mensaxes por páxina:';
$html_preferences = 'Preferencias';
$html_full_name_label = 'Nome completo:';
$html_email_address_label = 'Enderezo de correo electrónico:';
$html_ccself = 'Recibir unha copia';
$html_hide_addresses = 'Agochar os enderezos';
$html_outlook_quoting = 'Citar ao estilo Outlook';
$html_reply_to = 'Responder a';
$html_use_signature = 'Usar a sinatura';
$html_signature = 'Sinatura';
$html_signature_label = 'Sinatura:';
$html_reply_leadin_label = 'Marxe da resposta:';
$html_prefs_updated = 'Preferencias actualizadas';
$html_manage_folders_link = 'Administrar os cartafoles IMAP';
$html_manage_filters_link = 'Xestionar os filtros de correo electrónico';
$html_use_graphical_smilies = 'Usar emoticonas gráficas';
$html_sent_folder_label = 'Copiar os correos enviados nun cartafol específico:';
$html_trash_folder_label = 'Mover os correos borrados a un cartafol específico:';
$html_colored_quotes = 'Comiñas coloreadas';
$html_display_struct = 'Mostrar o texto estruturado';
$html_send_html_mail = 'Enviar o correo en formato HTML';
$html_folders = 'Cartafoles';
$html_folders_create_failed = 'Non se puido crear o cartafol!';
$html_folders_sub_failed = 'Non se puido subscribir ao cartafol!';
$html_folders_unsub_failed = 'Non se puido deixar de subscribir ao cartafol!';
$html_folders_rename_failed = 'O cartafol non puido ser renomeado!';
$html_folders_updated = 'Cartafoles actualizados';
$html_folder_subscribe = 'Subscribirse a';
$html_folder_rename = 'Renomear';
$html_folder_create = 'Crear un novo cartafol chamado';
$html_folder_remove = 'Deixar a subscrición a';
$html_folder_delete = 'Borrar';
$html_folder_to = 'para';
$html_filter_remove = 'Borrar';
$html_filter_body = 'Corpo da mensaxe';
$html_filter_subject = 'Asunto da mensaxe';
$html_filter_to = 'Campo "Para"';
$html_filter_cc = 'Campo "Cc"';
$html_filter_from = 'Campo "De"';
$html_filter_change_tip = 'Para cambiar un filtro simplemente sobreescríbao.';
$html_reapply_filters = 'Reaplicar de novo todos os filtros';
$html_filter_contains = 'contén';
$html_filter_name = 'Nome do filtro';
$html_filter_action = 'Acción do filtro';
$html_filter_moveto = 'Mover a';
$html_select_one = '--Seleccione un--';
$html_and = 'E';
$html_new_msg_in = 'Novas mensaxes en';
$html_or = 'ou';
$html_move = 'Mover';
$html_copy = 'Copiar';
$html_messages_to = 'as mensaxes seleccionadas a';
$html_gotopage = 'Ir á páxina';
$html_gotofolder = 'Ir ao cartafol';
$html_other_folders = 'Lista de cartafoles';
$html_page = 'Páxina';
$html_of = 'de';
$html_view_header = 'Ver a cabeceira';
$html_remove_header = 'Agochar a cabeceira';
$html_inbox = 'Caixa de entrada';
$html_new_msg = 'Escribir';
$html_reply = 'Responder';
$html_reply_short = 'Re:';
$html_reply_all = 'Responder a todos';
$html_forward = 'Reenviar';
$html_forward_short = 'Reenviar:';
$html_forward_info = 'A mensaxe reenviada será enviada como datos adxuntos desta.';
$html_delete = 'Borrar';
$html_new = 'Nova';
$html_mark = 'Borrar';
$html_att_label = 'Dato adxunto:';
$html_atts_label = 'Datos adxuntos:';
$html_unknown = '[descoñecido]';
$html_attach = 'Adxuntar';
$html_attach_forget = 'Debe adxuntar o seu ficheiro antes de enviar a súa mensaxe!';
$html_attach_delete = 'Eliminar a selección';
$html_attach_none = 'Debe seleccionar o ficheiro a adxuntar!';
$html_sort_by = 'Ordenar por';
$html_sort = 'Ordenar';
$html_from = 'De';
$html_from_label = 'De:';
$html_subject = 'Asunto';
$html_subject_label = 'Asunto:';
$html_date = 'Data';
$html_date_label = 'Data:';
$html_sent_label = 'Enviado o:';
$html_wrote = 'escribiu';
$html_size = 'Tamaño';
$html_totalsize = 'Tamaño total';
$html_kb = 'kB';
$html_mb = 'MB';
$html_gb = 'GB';
$html_bytes = 'bytes';
$html_filename = 'Nome do ficheiro';
$html_to = 'Para';
$html_to_label = 'Para:';
$html_cc = 'Cc';
$html_cc_label = 'Cc:';
$html_bcc_label = 'Cco:';
$html_nosubject = 'Sen asunto';
$html_send = 'Enviar';
$html_cancel = 'Cancelar';
$html_no_mail = 'Sen mensaxe.';
$html_logout = 'Saír';
$html_msg = 'Mensaxe';
$html_msgs = 'Mensaxes';
$html_configuration = 'Este servidor non está ben configurado!';
$html_priority = 'Prioridade';
$html_priority_label = 'Prioridade:';
$html_lowest = 'A menor';
$html_low = 'Baixa';
$html_normal = 'Normal';
$html_high = 'Alta';
$html_highest = 'A maior';
$html_flagged = 'Marcado';
$html_spam = 'Spam';
$html_spam_warning = 'Esta mensaxe clasificouse como spam.';
$html_receipt = 'Pedir unha confirmación de chegada';
$html_select = 'Seleccionar';
$html_select_all = 'Inverter a selección';
$html_select_contacts = 'Seleccionar contactos';
$html_loading_image = 'Cargando a imaxe';
$html_send_confirmed = 'O seu correo foi enviado correctamente';
$html_no_sendaction = 'Non se especificou ningunha acción. Probe a activar o JavaScript.';
$html_error_occurred = 'Houbo un erro';
$html_prefs_file_error = 'Non se pode abrir o ficheiro de preferencias.';
$html_wrap = 'Número de caracteres aos que axustar as mensaxes enviadas a:';
$html_wrap_none = 'Sen axuste';
$html_usenet_separator = 'Usar o separador "-- \n" antes da sinatura';
$html_mark_as = 'Marcar como';
$html_read = 'lido';
$html_unread = 'non lido';
$html_encoding_label = 'Codificación de caracteres:';
$html_add = 'Engadir';
$html_contacts = '%1$s contactos';
$html_modify = 'Modificar';
$html_back = 'Volver';
$html_contact_add = 'Engadir un novo contacto';
$html_contact_mod = 'Modificar un contacto';
$html_contact_first = 'Nome';
$html_contact_last = 'Apelidos';
$html_contact_nick = 'Alcume';
$html_contact_mail = 'Correo electrónico';
$html_contact_list = 'Lista de contactos de %1$s';
$html_contact_del = 'da lista de contactos';
$html_contact_count = '%1$d contactos';
$html_contact_err1 = 'O número máximo de contactos é "%1$d"';
$html_contact_err2 = 'Non pode engadir un novo contacto';
$html_contact_err3 = 'Non ten dereitos de acceso á lista de contactos';
$html_contact_none = 'Non se puido atopar ningún contacto.';
$html_del_msg = 'Quere borrar as mensaxes seleccionadas?';
$html_down_mail = 'Descargar';
$original_msg = '-- Mensaxe orixinal --';
$to_empty = 'O campo "Para" non pode estar baleiro!';
$html_images_warning = 'Pola súa seguridade, non se mostran as imaxes remotas.';
$html_images_display = 'Mostrar as imaxes';
$html_smtp_error_no_conn = 'Non se pode abrir conexión SMTP';
$html_smtp_error_unexpected = 'Resposta SMTP non esperada:';
$lang_could_not_connect = 'Non se puido conectar co servidor';
$lang_invalid_msg_num = 'Número de mensaxes inválido';
$html_file_upload_attack = 'Posibilidade de ataque na carga do ficheiro';
$html_invalid_email_address = 'Enderezo de correo electrónico inválido';
$html_invalid_msg_per_page = 'Número inválido de mensaxes por páxina';
$html_invalid_wrap_msg = 'Ancho de axuste de mensaxe inválido';
$html_seperate_msg_win = 'Mensaxes nunha ventá separada';
$html_err_file_contacts = 'Non se pode abrir o ficheiro de contactos.';
$html_session_file_error = 'Non se pode abrir o ficheiro de inicio de sesión.';
$html_login_not_allowed = 'Este rexistro non está permitido para a conexión.';
$lang_err_send_delay = 'Debe agardar entre dous correos (%1$d segundos)';
$html_search = 'Procurar';
